chicken-hackers
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Chicken-hackers] [PATCH 2/8] Rename chicken.ports module to chicken.por


From: Evan Hanson
Subject: [Chicken-hackers] [PATCH 2/8] Rename chicken.ports module to chicken.port
Date: Thu, 2 Mar 2017 21:50:38 +1300

---
 README                   |  2 +-
 chicken-bug.scm          |  2 +-
 chicken-install.scm      |  4 ++--
 chicken-status.scm       |  2 +-
 chicken-uninstall.scm    |  2 +-
 csi.scm                  |  2 +-
 defaults.make            |  2 +-
 distribution/manifest    |  8 ++++----
 eval.scm                 |  2 +-
 modules.scm              |  2 +-
 ports.scm => port.scm    |  6 +++---
 posixunix.scm            |  4 ++--
 posixwin.scm             |  4 ++--
 rules.make               | 28 ++++++++++++++--------------
 scrutinizer.scm          |  4 ++--
 stub.scm                 |  2 +-
 support.scm              |  4 ++--
 tcp.scm                  |  4 ++--
 tests/functor-tests.scm  |  2 +-
 tests/library-tests.scm  |  2 +-
 tests/module-tests-2.scm |  2 +-
 tests/port-tests.scm     |  2 +-
 tests/pp-test.scm        |  2 +-
 tests/r7rs-tests.scm     |  2 +-
 tests/reader-tests.scm   |  2 +-
 tests/reexport-tests.scm |  2 +-
 tests/runtests.sh        |  2 +-
 tests/sgrep.scm          |  2 +-
 tests/srfi-4-tests.scm   |  2 +-
 tests/srfi-45-tests.scm  |  2 +-
 tests/test-irregex.scm   |  2 +-
 types.db                 | 44 ++++++++++++++++++++++----------------------
 32 files changed, 77 insertions(+), 77 deletions(-)
 rename ports.scm => port.scm (99%)

diff --git a/README b/README
index 2e6c5802..32142132 100644
--- a/README
+++ b/README
@@ -297,7 +297,7 @@
        |   |       |-- chicken.lolevel.import.so
        |   |       |-- chicken.memory.import.so
        |   |       |-- chicken.pathname.import.so
-       |   |       |-- chicken.ports.import.so
+       |   |       |-- chicken.port.import.so
        |   |       |-- chicken.posix.import.so
        |   |       |-- chicken.pretty-print.import.so
        |   |       |-- chicken.random.import.so
diff --git a/chicken-bug.scm b/chicken-bug.scm
index 349bb08e..e2d294b8 100644
--- a/chicken-bug.scm
+++ b/chicken-bug.scm
@@ -31,7 +31,7 @@
        chicken.io
        chicken.keyword
        chicken.pathname
-       chicken.ports
+       chicken.port
        chicken.posix
        chicken.time)
 
diff --git a/chicken-install.scm b/chicken-install.scm
index 8cf77d4b..8d53bf5c 100644
--- a/chicken-install.scm
+++ b/chicken-install.scm
@@ -35,7 +35,7 @@
          chicken.io
          chicken.irregex
          chicken.pathname
-         chicken.ports
+         chicken.port
          chicken.posix
          chicken.pretty-print
          (only chicken.utils qs))
@@ -67,7 +67,7 @@
       "chicken.lolevel.import.so"
       "chicken.memory.import.so"
       "chicken.pathname.import.so"
-      "chicken.ports.import.so"
+      "chicken.port.import.so"
       "chicken.posix.import.so"
       "chicken.pretty-print.import.so"
       "chicken.random.import.so"
diff --git a/chicken-status.scm b/chicken-status.scm
index 5e9574a2..1d32e388 100644
--- a/chicken-status.scm
+++ b/chicken-status.scm
@@ -32,7 +32,7 @@
          chicken.format
          chicken.irregex
          chicken.pathname
-         chicken.ports
+         chicken.port
          chicken.posix
          chicken.pretty-print)
 
diff --git a/chicken-uninstall.scm b/chicken-uninstall.scm
index fb8e5d5f..15bc7871 100644
--- a/chicken-uninstall.scm
+++ b/chicken-uninstall.scm
@@ -32,7 +32,7 @@
          chicken.format
          chicken.irregex
          chicken.pathname
-         chicken.ports
+         chicken.port
          chicken.posix)
 
   (include "mini-srfi-1.scm")
diff --git a/csi.scm b/csi.scm
index 38d133d3..6ba9d987 100644
--- a/csi.scm
+++ b/csi.scm
@@ -51,7 +51,7 @@ EOF
        chicken.gc
        chicken.keyword
        chicken.io
-       chicken.ports
+       chicken.port
        chicken.pretty-print
        chicken.repl)
 
diff --git a/defaults.make b/defaults.make
index 4b16640c..b70a90c2 100644
--- a/defaults.make
+++ b/defaults.make
@@ -269,7 +269,7 @@ DYNAMIC_CHICKEN_IMPORT_LIBRARIES = bitwise errno fixnum 
flonum format \
        gc io keyword locative memory posix pretty-print random time
 DYNAMIC_CHICKEN_COMPILER_IMPORT_LIBRARIES = user-pass
 DYNAMIC_CHICKEN_UNIT_IMPORT_LIBRARIES = continuation data-structures \
-       eval expand file files internal irregex lolevel pathname ports \
+       eval expand file files internal irregex lolevel pathname port \
        read-syntax repl tcp utils
 
 # targets
diff --git a/distribution/manifest b/distribution/manifest
index 2d1459ec..8904266b 100644
--- a/distribution/manifest
+++ b/distribution/manifest
@@ -23,7 +23,7 @@ continuation.c
 data-structures.c
 dbg-stub.c
 debugger-client.c
-ports.c
+port.c
 file.c
 files.c
 extras.c
@@ -77,7 +77,7 @@ eval.scm
 extras.scm
 data-structures.scm
 debugger-client.scm
-ports.scm
+port.scm
 file.scm
 files.scm
 chicken-bug.mdoc
@@ -308,8 +308,8 @@ chicken.memory.import.scm
 chicken.memory.import.c
 chicken.pathname.import.scm
 chicken.pathname.import.c
-chicken.ports.import.scm
-chicken.ports.import.c
+chicken.port.import.scm
+chicken.port.import.c
 chicken.posix.import.scm
 chicken.posix.import.c
 chicken.pretty-print.import.scm
diff --git a/eval.scm b/eval.scm
index d2dac22e..1a017fc7 100644
--- a/eval.scm
+++ b/eval.scm
@@ -89,7 +89,7 @@
 (define-constant core-units
   '(chicken-syntax chicken-ffi-syntax continuation data-structures eval
     expand extras file files internal irregex library lolevel pathname
-    ports posix srfi-4 tcp repl read-syntax utils))
+    port posix srfi-4 tcp repl read-syntax utils))
 
 (define-constant cygwin-default-dynamic-load-libraries '("cygchicken-0"))
 (define-constant macosx-load-library-extension ".dylib")
diff --git a/modules.scm b/modules.scm
index 94a60697..0ce8178b 100644
--- a/modules.scm
+++ b/modules.scm
@@ -964,7 +964,7 @@
 (##sys#register-module-alias 'lolevel 'chicken.lolevel)
 (##sys#register-module-alias 'memory 'chicken.memory)
 (##sys#register-module-alias 'pathname 'chicken.pathname)
-(##sys#register-module-alias 'ports 'chicken.ports)
+(##sys#register-module-alias 'port 'chicken.port)
 (##sys#register-module-alias 'posix 'chicken.posix)
 (##sys#register-module-alias 'pretty-print 'chicken.pretty-print)
 (##sys#register-module-alias 'random 'chicken.random)
diff --git a/posixunix.scm b/posixunix.scm
index fa794f99..3119b547 100644
--- a/posixunix.scm
+++ b/posixunix.scm
@@ -27,7 +27,7 @@
 
 (declare
   (unit posix)
-  (uses scheduler irregex pathname extras files ports lolevel)
+  (uses scheduler irregex pathname extras files port lolevel)
   (disable-interrupts)
   (not inline ##sys#interrupt-hook ##sys#user-interrupt-hook))
 
@@ -86,7 +86,7 @@
        chicken.irregex
        chicken.memory
        chicken.pathname
-       chicken.ports
+       chicken.port
        chicken.time)
 
 (include "posix-common.scm")
diff --git a/posixwin.scm b/posixwin.scm
index 7d3021da..14ec70cf 100644
--- a/posixwin.scm
+++ b/posixwin.scm
@@ -62,7 +62,7 @@
 
 (declare
   (unit posix)
-  (uses scheduler data-structures irregex extras pathname files ports lolevel)
+  (uses scheduler data-structures irregex extras pathname files port lolevel)
   (disable-interrupts)
   (hide quote-arg-string)
   (not inline ##sys#interrupt-hook ##sys#user-interrupt-hook)
@@ -677,7 +677,7 @@ EOF
        chicken.irregex
        chicken.memory
        chicken.pathname
-       chicken.ports
+       chicken.port
        chicken.random
        chicken.time)
 
diff --git a/rules.make b/rules.make
index 0c1357e7..630df061 100644
--- a/rules.make
+++ b/rules.make
@@ -36,7 +36,7 @@ VPATH=$(SRCDIR)
 SETUP_API_OBJECTS_1 = setup-api setup-download
 
 LIBCHICKEN_SCHEME_OBJECTS_1 = \
-       library eval read-syntax repl data-structures pathname ports file \
+       library eval read-syntax repl data-structures pathname port file \
        files extras lolevel utils tcp srfi-4 continuation $(POSIXFILE) \
        internal irregex scheduler debugger-client profiler stub expand \
        modules chicken-syntax chicken-ffi-syntax build-version
@@ -593,7 +593,7 @@ scrutinizer.c: scrutinizer.scm mini-srfi-1.scm \
                chicken.format.import.scm \
                chicken.io.import.scm \
                chicken.pathname.import.scm \
-               chicken.ports.import.scm \
+               chicken.port.import.scm \
                chicken.pretty-print.import.scm
 lfa2.c: lfa2.scm mini-srfi-1.scm \
                chicken.compiler.support.import.scm \
@@ -616,7 +616,7 @@ support.c: support.scm mini-srfi-1.scm \
                chicken.keyword.import.scm \
                chicken.io.import.scm \
                chicken.pathname.import.scm \
-               chicken.ports.import.scm \
+               chicken.port.import.scm \
                chicken.pretty-print.import.scm \
                chicken.random.import.scm \
                chicken.time.import.scm
@@ -638,7 +638,7 @@ csi.c: csi.scm \
                chicken.gc.import.scm \
                chicken.keyword.import.scm \
                chicken.io.import.scm \
-               chicken.ports.import.scm \
+               chicken.port.import.scm \
                chicken.pretty-print.import.scm \
                chicken.repl.import.scm
 chicken-bug.c: chicken-bug.scm \
@@ -647,7 +647,7 @@ chicken-bug.c: chicken-bug.scm \
                chicken.io.import.scm \
                chicken.keyword.import.scm \
                chicken.pathname.import.scm \
-               chicken.ports.import.scm \
+               chicken.port.import.scm \
                chicken.posix.import.scm \
                chicken.time.import.scm
 chicken-profile.c: chicken-profile.scm \
@@ -659,7 +659,7 @@ chicken-status.c: chicken-status.scm \
                chicken.format.import.scm \
                chicken.irregex.import.scm \
                chicken.pathname.import.scm \
-               chicken.ports.import.scm \
+               chicken.port.import.scm \
                chicken.posix.import.scm \
                chicken.pretty-print.import.scm \
                setup-api.import.scm
@@ -671,7 +671,7 @@ chicken-install.c: chicken-install.scm \
                chicken.io.import.scm \
                chicken.irregex.import.scm \
                chicken.pathname.import.scm \
-               chicken.ports.import.scm \
+               chicken.port.import.scm \
                chicken.posix.import.scm \
                chicken.pretty-print.import.scm \
                setup-api.import.scm \
@@ -682,7 +682,7 @@ chicken-uninstall.c: chicken-uninstall.scm \
                chicken.format.import.scm \
                chicken.irregex.import.scm \
                chicken.pathname.import.scm \
-               chicken.ports.import.scm \
+               chicken.port.import.scm \
                chicken.posix.import.scm \
                setup-api.import.scm
 setup-api.c: setup-api.scm \
@@ -719,7 +719,7 @@ posixunix.c: posixunix.scm \
                chicken.irregex.import.scm \
                chicken.memory.import.scm \
                chicken.pathname.import.scm \
-               chicken.ports.import.scm \
+               chicken.port.import.scm \
                chicken.time.import.scm
 posixwin.c: posixwin.scm \
                chicken.bitwise.import.scm \
@@ -727,7 +727,7 @@ posixwin.c: posixwin.scm \
                chicken.irregex.import.scm \
                chicken.memory.import.scm \
                chicken.pathname.import.scm \
-               chicken.ports.import.scm \
+               chicken.port.import.scm \
                chicken.time.import.scm
 data-structures.c: data-structures.scm \
                chicken.foreign.import.scm
@@ -758,11 +758,11 @@ lolevel.c: lolevel.scm \
 pathname.c: pathname.scm \
                chicken.data-structures.import.scm \
                chicken.irregex.import.scm
-ports.c: ports.scm \
+port.c: port.scm \
                chicken.io.import.scm
 tcp.c: tcp.scm \
                chicken.foreign.import.scm \
-               chicken.ports.import.scm \
+               chicken.port.import.scm \
                chicken.time.import.scm
 utils.c: utils.scm \
                chicken.data-structures.import.scm \
@@ -824,8 +824,8 @@ data-structures.c: $(SRCDIR)data-structures.scm 
$(SRCDIR)common-declarations.scm
        $(bootstrap-lib) -emit-import-library chicken.data-structures
 pathname.c: $(SRCDIR)pathname.scm $(SRCDIR)common-declarations.scm
        $(bootstrap-lib) -emit-import-library chicken.pathname
-ports.c: $(SRCDIR)ports.scm $(SRCDIR)common-declarations.scm
-       $(bootstrap-lib) -emit-import-library chicken.ports
+port.c: $(SRCDIR)port.scm $(SRCDIR)common-declarations.scm
+       $(bootstrap-lib) -emit-import-library chicken.port
 file.c: $(SRCDIR)file.scm $(SRCDIR)common-declarations.scm
        $(bootstrap-lib) -emit-import-library chicken.file
 files.c: $(SRCDIR)files.scm $(SRCDIR)common-declarations.scm
diff --git a/scrutinizer.scm b/scrutinizer.scm
index a3ef1c42..2dbb4622 100644
--- a/scrutinizer.scm
+++ b/scrutinizer.scm
@@ -26,7 +26,7 @@
 
 (declare
   (unit scrutinizer)
-  (uses data-structures expand extras pathname ports support))
+  (uses data-structures expand extras pathname port support))
 
 (module chicken.compiler.scrutinizer
     (scrutinize load-type-database emit-type-file
@@ -41,7 +41,7 @@
        chicken.format
        chicken.io
        chicken.pathname
-       chicken.ports
+       chicken.port
        chicken.pretty-print)
 
 (include "tweaks")
diff --git a/stub.scm b/stub.scm
index c7739cd8..7da6774b 100644
--- a/stub.scm
+++ b/stub.scm
@@ -27,7 +27,7 @@
 
 (declare
   (unit default_stub)
-  (uses library eval data-structures ports extras)
+  (uses library eval data-structures port extras)
   (not safe) )
 
 (let loop () (return-to-host) (loop))
diff --git a/support.scm b/support.scm
index 9874cc36..9eab0452 100644
--- a/support.scm
+++ b/support.scm
@@ -27,7 +27,7 @@
 
 (declare (unit support)
         (not inline ##sys#user-read-hook) ; XXX: Is this needed?
-        (uses data-structures extras files internal pathname ports))
+        (uses data-structures extras files internal pathname port))
 
 (module chicken.compiler.support
     (compiler-cleanup-hook bomb collected-debugging-output debugging
@@ -85,7 +85,7 @@
        chicken.keyword
        chicken.io
        chicken.pathname
-       chicken.ports
+       chicken.port
        chicken.pretty-print
        chicken.random
        chicken.time)
diff --git a/tcp.scm b/tcp.scm
index 6f125d85..8e3d0e4c 100644
--- a/tcp.scm
+++ b/tcp.scm
@@ -27,7 +27,7 @@
 
 (declare
   (unit tcp)
-  (uses ports scheduler)
+  (uses port scheduler)
   (disable-interrupts) ; Avoid race conditions around errno/WSAGetLastError
   (foreign-declare #<<EOF
 #ifdef _WIN32
@@ -145,7 +145,7 @@ EOF
 
 (import scheme chicken)
 (import chicken.foreign
-       chicken.ports
+       chicken.port
        chicken.time)
 
 (include "common-declarations.scm")
diff --git a/tests/functor-tests.scm b/tests/functor-tests.scm
index 3f0588b1..173b8d4a 100644
--- a/tests/functor-tests.scm
+++ b/tests/functor-tests.scm
@@ -1,7 +1,7 @@
 ;;;; functor-tests.scm
 
 
-(use data-structures ports pretty-print)
+(use data-structures port pretty-print)
 
 
 (include "test.scm")
diff --git a/tests/library-tests.scm b/tests/library-tests.scm
index 3b7fb02b..81a2f242 100644
--- a/tests/library-tests.scm
+++ b/tests/library-tests.scm
@@ -1,6 +1,6 @@
 ;;;; library-tests.scm
 
-(use bitwise flonum keyword ports)
+(use bitwise flonum keyword port)
 
 (define-syntax assert-fail
   (syntax-rules ()
diff --git a/tests/module-tests-2.scm b/tests/module-tests-2.scm
index b4387410..be9eed76 100644
--- a/tests/module-tests-2.scm
+++ b/tests/module-tests-2.scm
@@ -2,7 +2,7 @@
 
 
 (module oo (output-of)
-  (import scheme chicken ports)
+  (import scheme chicken port)
   (define-syntax output-of 
     (syntax-rules ()
       ((_ exp) (with-output-to-string (lambda () exp)))))
diff --git a/tests/port-tests.scm b/tests/port-tests.scm
index 0f5fdbbb..30785465 100644
--- a/tests/port-tests.scm
+++ b/tests/port-tests.scm
@@ -1,4 +1,4 @@
-(require-extension data-structures files flonum format io ports posix srfi-4 
tcp utils)
+(require-extension data-structures files flonum format io port posix srfi-4 
tcp utils)
 
 (include "test.scm")
 (test-begin)
diff --git a/tests/pp-test.scm b/tests/pp-test.scm
index 500d6b70..a60670e5 100644
--- a/tests/pp-test.scm
+++ b/tests/pp-test.scm
@@ -1,7 +1,7 @@
 ;;;; pp-test.scm
 
 (use (only pretty-print pp)
-     (only ports with-output-to-string))
+     (only port with-output-to-string))
 
 (define (pp->string thing)
   (with-output-to-string (cut pp thing)))
diff --git a/tests/r7rs-tests.scm b/tests/r7rs-tests.scm
index da337179..75569147 100644
--- a/tests/r7rs-tests.scm
+++ b/tests/r7rs-tests.scm
@@ -1,6 +1,6 @@
 ;; R7RS Tests
 
-(use (only ports with-input-from-string with-output-to-string))
+(use (only port with-input-from-string with-output-to-string))
 
 ;; Copied from R4RS tests
 (define cur-section '())
diff --git a/tests/reader-tests.scm b/tests/reader-tests.scm
index 954b3f2d..bc0cb264 100644
--- a/tests/reader-tests.scm
+++ b/tests/reader-tests.scm
@@ -1,7 +1,7 @@
 ;;;; reader-tests.scm
 
 (use (only io read-line read-string)
-     (only ports with-input-from-string with-output-to-string)
+     (only port with-input-from-string with-output-to-string)
      (only read-syntax set-read-syntax! set-sharp-read-syntax!))
 
 (set-sharp-read-syntax! #\& (lambda (p) (read p) (values)))
diff --git a/tests/reexport-tests.scm b/tests/reexport-tests.scm
index d0ae6852..6109c3ae 100644
--- a/tests/reexport-tests.scm
+++ b/tests/reexport-tests.scm
@@ -29,7 +29,7 @@
 
 (compound-module
  big-chicken
- chicken ports files pretty-print data-structures)
+ chicken port files pretty-print data-structures)
 
 (module m3 ()
   (import scheme big-chicken)
diff --git a/tests/runtests.sh b/tests/runtests.sh
index 7c9fc2b6..644683e0 100755
--- a/tests/runtests.sh
+++ b/tests/runtests.sh
@@ -56,7 +56,7 @@ for x in \
     chicken.lolevel.import.so \
     chicken.memory.import.so \
     chicken.pathname.import.so \
-    chicken.ports.import.so \
+    chicken.port.import.so \
     chicken.posix.import.so \
     chicken.pretty-print.import.so \
     chicken.random.import.so \
diff --git a/tests/sgrep.scm b/tests/sgrep.scm
index b99f5dd2..227997b9 100644
--- a/tests/sgrep.scm
+++ b/tests/sgrep.scm
@@ -1,7 +1,7 @@
 ;;;; sgrep.scm - grepping benchmark
 
 
-(use io irregex ports utils)
+(use io irregex port utils)
 
 
 (define big-string
diff --git a/tests/srfi-4-tests.scm b/tests/srfi-4-tests.scm
index 610700dd..b6dcebc4 100644
--- a/tests/srfi-4-tests.scm
+++ b/tests/srfi-4-tests.scm
@@ -1,7 +1,7 @@
 ;;;; srfi-4-tests.scm
 
 
-(use srfi-4 ports)
+(use srfi-4 port)
 (import-for-syntax chicken)
 
 (define-syntax test1
diff --git a/tests/srfi-45-tests.scm b/tests/srfi-45-tests.scm
index ae14af7c..10a7a636 100644
--- a/tests/srfi-45-tests.scm
+++ b/tests/srfi-45-tests.scm
@@ -2,7 +2,7 @@
 ;;; That SRFI Copyright (C) André van Tonder (2003).
 
 (use (only format printf)
-     (only ports with-output-to-string))
+     (only port with-output-to-string))
 
 (define *errors* 0)
 
diff --git a/tests/test-irregex.scm b/tests/test-irregex.scm
index 0e839b8d..26330068 100644
--- a/tests/test-irregex.scm
+++ b/tests/test-irregex.scm
@@ -1,7 +1,7 @@
 ;;;: test-irregex.scm
 
 
-(use data-structures format io irregex ports)
+(use data-structures format io irregex port)
 
 (include "test.scm")
 
diff --git a/types.db b/types.db
index edd0c42a..1525a999 100644
--- a/types.db
+++ b/types.db
@@ -1843,28 +1843,28 @@
 (chicken.locative#make-locative (#(procedure #:clean #:enforce) 
chicken.locative#make-locative (* #!optional fixnum) locative))
 (chicken.locative#make-weak-locative (#(procedure #:clean #:enforce) 
chicken.locative#make-weak-locative (* #!optional fixnum) locative))
 
-;; ports
-
-(chicken.ports#call-with-input-string (#(procedure #:enforce) 
chicken.ports#call-with-input-string (string (procedure (input-port) . *)) . *))
-(chicken.ports#call-with-output-string (#(procedure #:enforce) 
chicken.ports#call-with-output-string ((procedure (output-port) . *)) string))
-(chicken.ports#copy-port (#(procedure #:enforce) chicken.ports#copy-port (* * 
#!optional (procedure (*) *) (procedure (* output-port) *)) undefined))
-(chicken.ports#make-input-port (#(procedure #:clean #:enforce) 
chicken.ports#make-input-port ((procedure () (or char eof)) (procedure () *) 
(procedure () . *) #!optional * * * *) input-port))
-(chicken.ports#make-output-port (#(procedure #:clean #:enforce) 
chicken.ports#make-output-port ((procedure (string) . *) (procedure () . *) 
#!optional (procedure () . *)) output-port))
-(chicken.ports#port-for-each (#(procedure #:enforce) 
chicken.ports#port-for-each ((procedure (*) *) (procedure () . *)) undefined))
-
-(chicken.ports#port-map
- (forall (a b) (#(procedure #:enforce) chicken.ports#port-map ((procedure (a) 
b) (procedure () a)) (list-of b))))
-
-(chicken.ports#port-fold (#(procedure #:enforce) chicken.ports#port-fold 
((procedure (* *) *) * (procedure () *)) *))
-(chicken.ports#make-bidirectional-port (#(procedure #:clean #:enforce) 
chicken.ports#make-bidirectional-port (input-port output-port) (refine (input 
output) port)))
-(chicken.ports#make-broadcast-port (#(procedure #:clean #:enforce) 
chicken.ports#make-broadcast-port (#!rest output-port) output-port))
-(chicken.ports#make-concatenated-port (#(procedure #:clean #:enforce) 
chicken.ports#make-concatenated-port (port #!rest input-port) input-port))
-(chicken.ports#with-error-to-port (#(procedure #:enforce) 
chicken.ports#with-error-to-port (output-port (procedure () . *)) . *))
-(chicken.ports#with-input-from-port (#(procedure #:enforce) 
chicken.ports#with-input-from-port (input-port (procedure () . *)) . *))
-(chicken.ports#with-input-from-string (#(procedure #:enforce) 
chicken.ports#with-input-from-string (string (procedure () . *)) . *))
-(chicken.ports#with-output-to-port (#(procedure #:enforce) 
chicken.ports#with-output-to-port (output-port (procedure () . *)) . *))
-(chicken.ports#with-output-to-string (#(procedure #:enforce) 
chicken.ports#with-output-to-string ((procedure () . *)) string))
-(chicken.ports#with-error-to-string (#(procedure #:enforce) 
chicken.ports#with-error-to-string ((procedure () . *)) string))
+;; port
+
+(chicken.port#call-with-input-string (#(procedure #:enforce) 
chicken.port#call-with-input-string (string (procedure (input-port) . *)) . *))
+(chicken.port#call-with-output-string (#(procedure #:enforce) 
chicken.port#call-with-output-string ((procedure (output-port) . *)) string))
+(chicken.port#copy-port (#(procedure #:enforce) chicken.port#copy-port (* * 
#!optional (procedure (*) *) (procedure (* output-port) *)) undefined))
+(chicken.port#make-input-port (#(procedure #:clean #:enforce) 
chicken.port#make-input-port ((procedure () (or char eof)) (procedure () *) 
(procedure () . *) #!optional * * * *) input-port))
+(chicken.port#make-output-port (#(procedure #:clean #:enforce) 
chicken.port#make-output-port ((procedure (string) . *) (procedure () . *) 
#!optional (procedure () . *)) output-port))
+(chicken.port#port-for-each (#(procedure #:enforce) chicken.port#port-for-each 
((procedure (*) *) (procedure () . *)) undefined))
+
+(chicken.port#port-map
+ (forall (a b) (#(procedure #:enforce) chicken.port#port-map ((procedure (a) 
b) (procedure () a)) (list-of b))))
+
+(chicken.port#port-fold (#(procedure #:enforce) chicken.port#port-fold 
((procedure (* *) *) * (procedure () *)) *))
+(chicken.port#make-bidirectional-port (#(procedure #:clean #:enforce) 
chicken.port#make-bidirectional-port (input-port output-port) (refine (input 
output) port)))
+(chicken.port#make-broadcast-port (#(procedure #:clean #:enforce) 
chicken.port#make-broadcast-port (#!rest output-port) output-port))
+(chicken.port#make-concatenated-port (#(procedure #:clean #:enforce) 
chicken.port#make-concatenated-port (port #!rest input-port) input-port))
+(chicken.port#with-error-to-port (#(procedure #:enforce) 
chicken.port#with-error-to-port (output-port (procedure () . *)) . *))
+(chicken.port#with-input-from-port (#(procedure #:enforce) 
chicken.port#with-input-from-port (input-port (procedure () . *)) . *))
+(chicken.port#with-input-from-string (#(procedure #:enforce) 
chicken.port#with-input-from-string (string (procedure () . *)) . *))
+(chicken.port#with-output-to-port (#(procedure #:enforce) 
chicken.port#with-output-to-port (output-port (procedure () . *)) . *))
+(chicken.port#with-output-to-string (#(procedure #:enforce) 
chicken.port#with-output-to-string ((procedure () . *)) string))
+(chicken.port#with-error-to-string (#(procedure #:enforce) 
chicken.port#with-error-to-string ((procedure () . *)) string))
 
 ;; errno
 
diff --git a/ports.scm b/port.scm
similarity index 99%
rename from ports.scm
rename to port.scm
index 2a2f125b..3964ed5a 100644
--- a/ports.scm
+++ b/port.scm
@@ -1,4 +1,4 @@
 ;;; ports.scm - Optional non-standard ports
 ;
 ; Copyright (c) 2008-2017, The CHICKEN Team
 ; Copyright (c) 2000-2007, Felix L. Winkelmann
@@ -33,10 +33,10 @@
 
 
 (declare
-  (unit ports)
+  (unit port)
   (uses extras))
 
-(module chicken.ports
+(module chicken.port
   (call-with-input-string
    call-with-output-string
    copy-port
@@ -1,4 +1,4 @@
-;;; ports.scm - Optional non-standard ports
+;;; port.scm - Optional non-standard ports
 ;
 ; Copyright (c) 2008-2017, The CHICKEN Team
-- 
2.11.0




reply via email to

[Prev in Thread] Current Thread [Next in Thread]